==> mathmoon-0.1.0.tar.bz2: mathmoon-0.1.0/src/chooseone/chooseonepanel.h <==
// A mathematical game
// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef CHOOSEONEPANEL_H
#define CHOOSEONEPANEL_H

#include <wx/object.h>
#include <wx/wxexpr.h>
#include <wx/panel.h>
#include <wx/timer.h>
#include <wx/dc.h>
#include <wx/listctrl.h>
#include <new>

#include <config.h>
#include "../checksetup.h"

#include "../exceptions.h"
#include "../mainwindow.h"

class ChooseOne;
class ChooseOneData;

class ChooseOnePanel: public wxPanel
{
public:
  ChooseOnePanel(ChooseOne *co, ChooseOneData *cod)
    throw(Exception);
  
  virtual ~ChooseOnePanel();
private:
  void Start() throw();

public:

  void GiveOneFocus() throw();

  void OnItemActivated(wxListEvent &event) throw();
  void OnChar(wxKeyEvent &event) throw();


  void OnPaint(wxPaintEvent &event) throw();
  void Draw(wxDC &dc) throw();

protected:
  DECLARE_EVENT_TABLE();

private:
  ChooseOne *m_co;
  ChooseOneData *m_data;
};

#include "chooseone.h"
#include "chooseonedata.h"

#endif // CHOOSEONEPANEL_H

// 
// Local Variables:
// mode: c++
// End:

==> mathmoon-0.3.1.tar.bz2: mathmoon-0.3.1/src/chooseone/chooseonepanel.h <==
// A mathematical game
// Copyright (C) 2004-2005 by Christian von Schultz <schultz@linux.nu>

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifndef CHOOSEONEPANEL_H
#define CHOOSEONEPANEL_H

#include <wx/object.h>
#include <wx/wxexpr.h>
#include <wx/panel.h>
#include <wx/timer.h>
#include <wx/dc.h>
#include <wx/listctrl.h>
#include <new>

#include <config.h>
#include "../checksetup.h"

#include "../exceptions.h"
#include "../mainwindow.h"
#include "../one/onepanel.h"

class ChooseOne;
class ChooseOneData;

class ChooseOnePanel: public One::OnePanel
{
public:
  ChooseOnePanel(ChooseOne *co, ChooseOneData *cod)
    throw(Exception);
  
  virtual ~ChooseOnePanel();

protected:
  virtual wxWindow *cMakeAnswerCtrl(::One::Screen *current) throw(Exception);

public:

  void OnItemActivated(wxListEvent &event) throw();
  void OnChar(wxKeyEvent &event) throw();

protected:
  DECLARE_EVENT_TABLE();
};

#include "chooseone.h"
#include "chooseonedata.h"

#endif // CHOOSEONEPANEL_H

// 
// Local Variables:
// mode: c++
// End:
